@@ -3,10 +3,10 @@ Database models for edx_rbac.
 """
 
 from django.conf import settings
+from django.core.exceptions import FieldDoesNotExist
 from django.db import models
 from django.db.models.base import ModelBase
-from django.db.models.fields import FieldDoesNotExist
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from model_utils.models import TimeStampedModel
 
 
@@ -104,10 +104,7 @@ class UserRoleAssignment(TimeStampedModel, metaclass=UserRoleAssignmentCreator):
         Return human-readable string representation.
         """
         # pylint: disable=no-member
-        return '{user}:{role}'.format(
-            user=self.user.id,
-            role=self.role.name,
-        )
+        return f'{self.user.id}:{self.role.name}'
 
     def __repr__(self):
         """
